@@ -1,25 +1,31 @@
+#!/usr/bin/env python2.7
+# -*- coding: utf-8 -*-
+
+
 __author__ = 'yarnaid'
 
 import os
-import io
+import cStringIO as StringIO
 import subprocess as sp
 
 import numpy as np
 
-try:
-    import tools.tools as tools
-    import properties
-    import ext.angles as angles
-except:
-    import glespy.tools.tools as tools
-    import glespy.properties as properties
-    import glespy.ext.angles as angles
+import glespy.tools.tools as tools
+import glespy.properties as properties
+from glespy.ext.angles import Zone, Angle
+
+
+rtypes = ['c', 'h', 'v', 'p', 'C', 'H', 'V', 'P']
+
+
+def check_file(name):
+    if not os.path.exists(name):
+        raise IOError('Fail in proceeding file {}'.format(name))
+    return name
 
 
 def get_map_attrs(map_name):
-    if not os.path.exists(map_name):
-        raise StandardError('[%s]: no such file "%s"' %
-                            (get_map_attrs.__name__, map_name))
+    check_file(map_name)
     output = tools.run_cmd(
         [tools.glesp['difmap'], '-st', map_name], debug_msg='getting attrs')
     output = output[0].split()
@@ -35,9 +41,7 @@ def get_map_attrs(map_name):
 
 
 def map_to_alm(map_name, alm_name=None, **kwargs):
-    if not os.path.exists(map_name):
-        raise StandardError('[%s]: no such file "%s"' %
-                            (map_to_alm.__name__, map_name))
+    check_file(map_name)
     attrs = get_map_attrs(map_name)
     tmp_tresh_map = tools.get_out_name(suffix='map_to_alm_trash.fit')
     lmax = (attrs['nx'] - 1) / 2
@@ -50,23 +54,22 @@ def map_to_alm(map_name, alm_name=None, **kwargs):
         os.remove(tmp_tresh_map)
     except:
         pass
-    return alm_name, lmax
+    check_file(alm_name)
+    return alm_name
 
 
 def map_to_gif(map_name, gif_name=None, **kwargs):
-    if not os.path.exists(map_name):
-        raise StandardError('[%s]: no such file "%s"' %
-                            (map_to_gif.__name__, map_name))
-    gif_name = tools.get_out_name(gif_name, '.gif')
+    check_file(map_name)
+    gif_name = tools.get_out_name(gif_name, suffix='.gif')
     args = [tools.binaries['f2fig'], map_name, '-o', gif_name]
     args.extend(kwargs_to_glesp_args(**kwargs))
     tools.run_cmd(args, debug_msg='map to gif')
+    check_file(gif_name)
     return gif_name
 
 
 def show_map(map_name, **kwargs):
-    if not os.path.exists(map_name):
-        raise StandardError('[%s]: file "%s" does not exists' % (map_name))
+    check_file(map_name)
     gif = map_to_gif(map_name, **kwargs)
     args = [tools.binaries['viewer'], gif]
     # args.extend(kwargs_to_glesp_args(**kwargs))
@@ -122,49 +125,69 @@ def kwargs_props_to_glesp_args(**kwargs):
 
 
 def alm_to_map(alm_name, map_name=None, **kwargs):
-    if len({'nx', 'np', 'lmax', 'l', 'lmin'}.intersection(kwargs)) < 1:
-        raise ValueError(
-            '[%s]: l or lmax or nx or np must be given' % alm_to_map.__name__)
+    check_file(alm_name)
     opt_args = kwargs_props_to_glesp_args(**kwargs)
-    map_name = tools.get_out_name(map_name, 'alm_from_map.fit')
+    map_name = tools.get_out_name(map_name, suffix='alm_from_map.fit')
     args = [tools.binaries['cl2map'], '-falm', alm_name, '-o', map_name]
     args.extend(opt_args)
     tools.run_cmd(args, debug_msg='alm to map')
+    print(opt_args)
+    print(args)
+    check_file(map_name)
     return map_name
 
 
 def map_to_hist(map_name, hn=20, **kwargs):
+    check_file(map_name)
     tmp_hist = tools.get_out_name(suffix='hist_from_map.txt')
     args = [tools.binaries['difmap'], map_name,
             '-st', '-hn', hn, '-hf', tmp_hist]
     args.extend(kwargs_to_glesp_args(**kwargs))
+    args = remove_nx_np(args)
     tools.run_cmd(args, debug_msg='map to hist')
     hist_data = np.loadtxt(tmp_hist)
     os.remove(tmp_hist)
     return hist_data
 
 
+def remove_nx_np(bad_args):
+    args = bad_args
+    for k in ['-nx', '-np']:
+        try:
+            i = args.index(k)
+            del args[i + 1], args[i]
+        except:
+            pass
+    return args
+
+
 def alm_to_cl(alm_name, **kwargs):
     if len({'lmax', 'l', 'lmin'}.intersection(kwargs)) < 1:
         raise ValueError(
             '[%s]: lmax or l or lmin must be given' % (alm_to_cl.__name__))
     opt_args = kwargs_props_to_glesp_args(**kwargs)
-    args = [tools.binaries['alm2dl'], '-cl']
+    args = [tools.binaries['alm2dl'], '-cl', alm_name]
     args.extend(opt_args)
+    args = remove_nx_np(args)
     with open(os.devnull) as stderr:
+        args = map(str, args)
         raw_data = sp.check_output(args, stderr=stderr)
-    cl_data = np.loadtxt(io.StringIO(raw_data))
+    cl_data = np.loadtxt(StringIO.StringIO(raw_data))
     return cl_data
 
 
 def mask_map(map_name, mask_name, masked_map_name=None, **kwargs):
+    check_file(map_name)
+    check_file(mask_name)
     masked_map_name = tools.get_out_name(
-        masked_map_name, 'masked_from_map.fit')
+        masked_map_name, suffix='masked_from_map.fit')
     opt_args = kwargs_props_to_glesp_args(**kwargs)
     args = [tools.binaries['difmap'], map_name,
             '-mf', mask_name, '-o', masked_map_name]
     args.extend(opt_args)
+    args = remove_nx_np(args)
     tools.run_cmd(args, debug_msg='mask map')
+    check_file(masked_map_name)
     return masked_map_name
 
 
@@ -174,16 +197,18 @@ def points_to_map(points_name, map_name=None, **kwargs):
             '[{}]: nx or np or lmax or l or lmin must be given'.format(
                 alm_to_cl.__name__)
         )
-    map_name = tools.get_out_name(map_name, 'map_from_points.fit')
+    map_name = tools.get_out_name(map_name, suffix='map_from_points.fit')
     opt_args = kwargs_props_to_glesp_args(**kwargs)
     args = [tools.binaries['mappat'], '-fp', points_name, '-o', map_name]
     args.extend(opt_args)
     tools.run_cmd(args, debug_msg='point to map')
-    return map_name
+    return check_file(map_name)
 
 
 def smooth_alm(alm_name, smooth_window, smoothed_name=None, **kwargs):
-    smoothed_name = tools.get_out_name(smoothed_name, 'smoothed_alm.fit')
+    check_file(alm_name)
+    smoothed_name = tools.get_out_name(
+        smoothed_name, suffix='smoothed_alm.fit')
     opt_args = []
     try:
         opt_args = kwargs_props_to_glesp_args(**kwargs)
@@ -193,11 +218,14 @@ def smooth_alm(alm_name, smooth_window, smoothed_name=None, **kwargs):
             '-fw', smooth_window, '-o', smoothed_name]
     args.extend(opt_args)
     tools.run_cmd(args, debug_msg='smooth alm')
-    return smoothed_name
+    return check_file(smoothed_name)
 
 
 def correlate(map1, map2, correlation_window, correlated_map=None, **kwargs):
-    correlated_map = tools.get_out_name(correlated_map, 'correlated_map.fit')
+    check_file(map1)
+    check_file(map2)
+    correlated_map = tools.get_out_name(
+        correlated_map, suffix='correlated_map.fit')
     try:
         opt_args = kwargs_props_to_glesp_args(**kwargs)
     except:
@@ -205,17 +233,20 @@ def correlate(map1, map2, correlation_window, correlated_map=None, **kwargs):
     args = [tools.binaries['difmap'], map1, map2,
             '-cw', correlation_window, '-o', correlated_map]
     args.extend(opt_args)
+    args = remove_nx_np(args)
     tools.run_cmd(args, debug_msg='correlate maps')
-    return correlated_map
+    return check_file(correlated_map)
 
 
 def sum_map(map1_name, map2_name, mult=[1.0, -1.0], summed_map=None, **kwargs):
+    check_file(map1_name)
+    check_file(map2_name)
     attrs1 = get_map_attrs(map1_name)
     attrs2 = get_map_attrs(map2_name)
     if attrs1 != attrs2:
         raise ValueError(
             '[{}]: maps has different resolution'.format(__name__))
-    summed_map = tools.get_out_name(summed_map, 'summed.fit')
+    summed_map = tools.get_out_name(summed_map, suffix='summed.fit')
     for i in range(1, 2, 1):
         k = 'c{}'.format(i)
         if k in kwargs.keys():
@@ -230,11 +261,12 @@ def sum_map(map1_name, map2_name, mult=[1.0, -1.0], summed_map=None, **kwargs):
     args = [tools.binaries['difmap'], '-c1', mult[0],
             '-c2', mult[1], map1_name, map2_name, '-o', summed_map]
     args.extend(opt_args)
+    args = remove_nx_np(args)
     tools.run_cmd(args, debug_msg='sum maps')
-    return summed_map
+    return check_file(summed_map)
 
 
-def rotate_alm(alm_name, rotated_name=None, **kwargs):
+def rotate_alm(alm_name, rotated_name=None, angle=None, **kwargs):
     """
     phi and psi are angels in radians
     :param dphi
@@ -242,23 +274,76 @@ def rotate_alm(alm_name, rotated_name=None, **kwargs):
     :param dtheta
     :return: rotated_alm_name
     """
-    rotated_named = tools.get_out_name(rotated_name, 'rotated_alm.fit')
-    opt_args = kwargs_to_glesp_args(**kwargs)
-    args = [tools.binaries['difalm'], alm_name, '-o', rotated_named]
+    if not isinstance(angle, (Angle, type(None))):
+        raise TypeError(
+            'Angle must be an instance of {} class, {}.got'.format(
+                angle.Angle.__class__.__name__, type(angle),
+            )
+        )
+    check_file(alm_name)
+    rotated_name = tools.get_out_name(rotated_name, suffix='rotated_alm.fit')
+    opt_args = kwargs.copy()
+    if angle:
+        for k in ['dphi', 'dtheta', 'dp', 'dt']:
+            opt_args.pop(k, None)
+        opt_args['dtheta'] = angle.theta_d()
+        opt_args['dphi'] = angle.phi_d()
+
+    opt_args = kwargs_to_glesp_args(**opt_args)
+    args = [tools.binaries['difalm'], alm_name, '-o', rotated_name]
     args.extend(opt_args)
     tools.run_cmd(args, debug_msg='rotate alm')
-    return rotated_named
+    return check_file(rotated_name)
 
 
 def cut_map_zone(map_name, zone, cutted_map=None, **kwargs):
-    if not isinstance(zone, angles.Zone):
+    if not isinstance(zone, Zone):
         raise AssertionError('zone must be an instance of {}'.format(
-            angles.Zone.__class__.__name__
+            Zone.__class__.__name__
         ))
-    cutted_map = tools.get_out_name(cutted_map, 'cutted_map.fit')
+    check_file(map_name)
+    cutted_map = tools.get_out_name(cutted_map, suffix='cutted_map.fit')
     opt_args = kwargs_to_glesp_args(**kwargs)
     args = [tools.binaries['difmap'], map_name, '-keep', zone(),
             '-o', cutted_map]
     args.extend(opt_args)
+    args = remove_nx_np(args)
     tools.run_cmd(args, debug_msg='cut map zone')
-    return cutted_map
+    try:
+        return check_file(cutted_map)
+    except:
+        tools.debug(args)
+        raise IOError('Failed to calc file {}'.format(cutted_map))
+
+
+def reflect_map(map_name, rtype, reflected_name=None, **kwargs):
+    if rtype not in rtypes:
+        raise ValueError(
+            'Reflection type must be in {}, got {}'.format(rtypes, rtype)
+        )
+    reflected_name = tools.get_out_name(
+        reflected_name, suffix='reflected_map.fit',
+    )
+    check_file(map_name)
+    args = [tools.binaries['difmap'], map_name, '-o', reflected_name,
+            '-mir{}'.format(rtype.upper()),
+            ]
+    opt_args = kwargs_to_glesp_args(**kwargs)
+    args.extend(opt_args)
+    args = remove_nx_np(args)
+    tools.run_cmd(args, debug_msg='reflect map')
+    return check_file(reflected_name)
+
+
+def mult_map(map_name, mult, mult_name=None, **kwargs):
+    check_file(map_name)
+    mult_name = tools.get_out_name(
+        mult_name,
+        suffix='multed_{}_map_fit'.format(mult),
+    )
+    opt_args = kwargs_to_glesp_args(**kwargs)
+    args = [tools.binaries['difmap'], map_name, '-cf', mult, '-o', mult_name]
+    args.extend(opt_args)
+    args = remove_nx_np(args)
+    tools.run_cmd(args, debug_msg='multiplying map')
+    return check_file(mult_name)
