@@ -9,7 +9,8 @@ except:
     import glespy.tools.colorer
 
 
-logging.basicConfig(format='[%(funcName)s][%(asctime)s] %(levelname)s: %(message)s')
+logging.basicConfig(
+    format='[%(funcName)s][%(asctime)s] %(levelname)s: %(message)s')
 logging.basicConfig(datefmt='%m/%d/%Y %I:%M:%S %p')
 logging.basicConfig(level=logging.INFO)
 logging.basicConfig(levelname=logging.INFO)
