@@ -5,10 +5,7 @@ import subprocess as sp
 import tempfile
 import time
 
-try:
-    import tools.logger as lg
-except:
-    import glespy.tools.logger as lg
+import glespy.tools.logger as lg
 
 
 glesp_exec = '/usr/local/bin'
@@ -36,7 +33,7 @@ debug = lg.logger.debug
 
 __all__ = ["run_cmd", "get_out_name", "glesp", "binaries",
            "info", "warn", "debug", "error", "critical", "log", "exception",
-]
+           ]
 
 
 def run_cmd(args, debug_msg=None,
@@ -49,7 +46,7 @@ def run_cmd(args, debug_msg=None,
                     stdout=stdout,
                     stderr=stderr,
                     shell=shell,
-    )
+                    )
     proc.wait()
     res = proc.communicate()
     # debug(args[0])
@@ -66,12 +63,13 @@ def run_cmd(args, debug_msg=None,
     return res
 
 
-def get_out_name(out_name=None, suffix='tmp', dir=None, **kwargs):
+def get_out_name(out_name=None, suffix='tmp', dir='/tmp', **kwargs):
     # dir not tested!!!
     res = out_name
     if not res:
         tmp_file = tempfile.NamedTemporaryFile(dir=dir,
-            suffix='_'.join([str(time.time()), suffix]),
-            delete=kwargs.get('delete', True))
+                                               suffix='_'.join(
+                                                   [str(time.time()), suffix]),
+                                               delete=kwargs.get('delete', True))
         res = tmp_file.name
     return res
